==> azure_mgmt_resources-0.2.0.crate: azure_mgmt_resources-0.2.0/README.md <==
# azure_mgmt_resources crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/resources/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-resources-2021-04`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-changes-2022-03` has 2 operations from 1 API versions: `2022-03-01-preview`. Use crate feature `package-changes-2022-03` to enable. The operations will be in the `package_changes_2022_03` module.
- `package-policy-2021-06` has 41 operations from 4 API versions: `2020-06-01`, `2020-07-01-preview`, `2020-09-01`, `2021-06-01`. Use crate feature `package-policy-2021-06` to enable. The operations will be in the `package_policy_2021_06` module.
- `package-privatelinks-2020-05` has 9 operations from 1 API versions: `2020-05-01`. Use crate feature `package-privatelinks-2020-05` to enable. The operations will be in the `package_privatelinks_2020_05` module.
- `package-locks-2020-05` has 17 operations from 1 API versions: `2020-05-01`. Use crate feature `package-locks-2020-05` to enable. The operations will be in the `package_locks_2020_05` module.
- `package-resources-2021-04` has 95 operations from 1 API versions: `2021-04-01`. Use crate feature `package-resources-2021-04` to enable. The operations will be in the `package_resources_2021_04` module.
- `package-locks-2017-04` has 17 operations from 1 API versions: `2017-04-01`. Use crate feature `package-locks-2017-04` to enable. The operations will be in the `package_locks_2017_04` module.
- `package-preview-2020-08` has 3 operations from 1 API versions: `2020-08-21-preview`. Use crate feature `package-preview-2020-08` to enable. The operations will be in the `package_preview_2020_08` module.
- `package-subscriptions-2021-01` has 6 operations from 1 API versions: `2021-01-01`. Use crate feature `package-subscriptions-2021-01` to enable. The operations will be in the `package_subscriptions_2021_01` module.
- `package-deploymentscripts-2020-10` has 8 operations from 1 API versions: `2020-10-01`. Use crate feature `package-deploymentscripts-2020-10` to enable. The operations will be in the `package_deploymentscripts_2020_10` module.
- `package-deploymentscripts-2019-10-preview` has 8 operations from 1 API versions: `2019-10-01-preview`. Use crate feature `package-deploymentscripts-2019-10-preview` to enable. The operations will be in the `package_deploymentscripts_2019_10_preview` module.
- `package-features-2021-07` has 11 operations from 1 API versions: `2021-07-01`. Use crate feature `package-features-2021-07` to enable. The operations will be in the `package_features_2021_07` module.
- `package-features-2015-12` has 6 operations from 1 API versions: `2015-12-01`. Use crate feature `package-features-2015-12` to enable. The operations will be in the `package_features_2015_12` module.
- `package-locks-2016-09` has 17 operations from 1 API versions: `2016-09-01`. Use crate feature `package-locks-2016-09` to enable. The operations will be in the `package_locks_2016_09` module.
- `package-locks-2015-01` has 11 operations from 1 API versions: `2015-01-01`. Use crate feature `package-locks-2015-01` to enable. The operations will be in the `package_locks_2015_01` module.
- `package-policy-2019-09` has 30 operations from 1 API versions: `2019-09-01`. Use crate feature `package-policy-2019-09` to enable. The operations will be in the `package_policy_2019_09` module.
- `package-policy-2019-06` has 29 operations from 1 API versions: `2019-06-01`. Use crate feature `package-policy-2019-06` to enable. The operations will be in the `package_policy_2019_06` module.
- `package-policy-2019-01` has 29 operations from 1 API versions: `2019-01-01`. Use crate feature `package-policy-2019-01` to enable. The operations will be in the `package_policy_2019_01` module.
- `package-policy-2018-05` has 29 operations from 1 API versions: `2018-05-01`. Use crate feature `package-policy-2018-05` to enable. The operations will be in the `package_policy_2018_05` module.
- `package-policy-2018-03` has 29 operations from 1 API versions: `2018-03-01`. Use crate feature `package-policy-2018-03` to enable. The operations will be in the `package_policy_2018_03` module.
- `package-policy-2017-06` has 29 operations from 2 API versions: `2016-12-01`, `2017-06-01-preview`. Use crate feature `package-policy-2017-06` to enable. The operations will be in the `package_policy_2017_06` module.
- `package-pure-policy-2017-06` has 19 operations from 1 API versions: `2017-06-01-preview`. Use crate feature `package-pure-policy-2017-06` to enable. The operations will be in the `package_pure_policy_2017_06` module.
- `package-templatespecs-2021-05` has 11 operations from 1 API versions: `2021-05-01`. Use crate feature `package-templatespecs-2021-05` to enable. The operations will be in the `package_templatespecs_2021_05` module.
- `package-templatespecs-2021-03-preview` has 11 operations from 1 API versions: `2021-03-01-preview`. Use crate feature `package-templatespecs-2021-03-preview` to enable. The operations will be in the `package_templatespecs_2021_03_preview` module.
- `package-templatespecs-2019-06-preview` has 11 operations from 1 API versions: `2019-06-01-preview`. Use crate feature `package-templatespecs-2019-06-preview` to enable. The operations will be in the `package_templatespecs_2019_06_preview` module.
- `package-policy-2016-12` has 19 operations from 1 API versions: `2016-12-01`. Use crate feature `package-policy-2016-12` to enable. The operations will be in the `package_policy_2016_12` module.
- `package-policy-2016-04` has 13 operations from 1 API versions: `2016-04-01`. Use crate feature `package-policy-2016-04` to enable. The operations will be in the `package_policy_2016_04` module.
- `package-policy-2015-10` has 13 operations from 1 API versions: `2015-10-01-preview`. Use crate feature `package-policy-2015-10` to enable. The operations will be in the `package_policy_2015_10` module.
- `package-resources-2021-01` has 94 operations from 1 API versions: `2021-01-01`. Use crate feature `package-resources-2021-01` to enable. The operations will be in the `package_resources_2021_01` module.
- `package-resources-2020-10` has 94 operations from 1 API versions: `2020-10-01`. Use crate feature `package-resources-2020-10` to enable. The operations will be in the `package_resources_2020_10` module.
- `package-resources-2020-08` has 93 operations from 1 API versions: `2020-08-01`. Use crate feature `package-resources-2020-08` to enable. The operations will be in the `package_resources_2020_08` module.
- `package-resources-2020-06` has 93 operations from 1 API versions: `2020-06-01`. Use crate feature `package-resources-2020-06` to enable. The operations will be in the `package_resources_2020_06` module.
- `package-resources-2019-10` has 92 operations from 1 API versions: `2019-10-01`. Use crate feature `package-resources-2019-10` to enable. The operations will be in the `package_resources_2019_10` module.
- `package-resources-2019-08` has 86 operations from 1 API versions: `2019-08-01`. Use crate feature `package-resources-2019-08` to enable. The operations will be in the `package_resources_2019_08` module.
- `package-resources-2019-07` has 86 operations from 1 API versions: `2019-07-01`. Use crate feature `package-resources-2019-07` to enable. The operations will be in the `package_resources_2019_07` module.
- `package-resources-2019-0510` has 64 operations from 1 API versions: `2019-05-10`. Use crate feature `package-resources-2019-0510` to enable. The operations will be in the `package_resources_2019_0510` module.
- `package-resources-2019-05` has 62 operations from 1 API versions: `2019-05-01`. Use crate feature `package-resources-2019-05` to enable. The operations will be in the `package_resources_2019_05` module.
- `package-resources-2019-03` has 52 operations from 1 API versions: `2019-03-01`. Use crate feature `package-resources-2019-03` to enable. The operations will be in the `package_resources_2019_03` module.
- `package-resources-2018-05` has 52 operations from 1 API versions: `2018-05-01`. Use crate feature `package-resources-2018-05` to enable. The operations will be in the `package_resources_2018_05` module.
- `package-resources-2018-02` has 41 operations from 1 API versions: `2018-02-01`. Use crate feature `package-resources-2018-02` to enable. The operations will be in the `package_resources_2018_02` module.
- `package-resources-2017-05` has 41 operations from 1 API versions: `2017-05-10`. Use crate feature `package-resources-2017-05` to enable. The operations will be in the `package_resources_2017_05` module.
- `package-resources-2016-09` has 40 operations from 1 API versions: `2016-09-01`. Use crate feature `package-resources-2016-09` to enable. The operations will be in the `package_resources_2016_09` module.
- `package-resources-2016-07` has 35 operations from 1 API versions: `2016-07-01`. Use crate feature `package-resources-2016-07` to enable. The operations will be in the `package_resources_2016_07` module.
- `package-resources-2016-02` has 35 operations from 1 API versions: `2016-02-01`. Use crate feature `package-resources-2016-02` to enable. The operations will be in the `package_resources_2016_02` module.
- `package-resources-2015-11` has 47 operations from 1 API versions: `2015-11-01`. Use crate feature `package-resources-2015-11` to enable. The operations will be in the `package_resources_2015_11` module.
- `package-subscriptions-2020-01` has 7 operations from 1 API versions: `2020-01-01`. Use crate feature `package-subscriptions-2020-01` to enable. The operations will be in the `package_subscriptions_2020_01` module.
- `package-subscriptions-2019-11` has 7 operations from 1 API versions: `2019-11-01`. Use crate feature `package-subscriptions-2019-11` to enable. The operations will be in the `package_subscriptions_2019_11` module.
- `package-subscriptions-2019-06` has 7 operations from 1 API versions: `2019-06-01`. Use crate feature `package-subscriptions-2019-06` to enable. The operations will be in the `package_subscriptions_2019_06` module.
- `package-subscriptions-2018-06` has 7 operations from 1 API versions: `2018-06-01`. Use crate feature `package-subscriptions-2018-06` to enable. The operations will be in the `package_subscriptions_2018_06` module.
- `package-subscriptions-2016-06` has 7 operations from 1 API versions: `2016-06-01`. Use crate feature `package-subscriptions-2016-06` to enable. The operations will be in the `package_subscriptions_2016_06` module.
- `package-subscriptions-2015-11` has 6 operations from 1 API versions: `2015-11-01`. Use crate feature `package-subscriptions-2015-11` to enable. The operations will be in the `package_subscriptions_2015_11` module.
- `package-links-2016-09` has 6 operations from 1 API versions: `2016-09-01`. Use crate feature `package-links-2016-09` to enable. The operations will be in the `package_links_2016_09` module.
- `package-managedapplications-2019-07` has 3 operations from 1 API versions: `2019-07-01`. Use crate feature `package-managedapplications-2019-07` to enable. The operations will be in the `package_managedapplications_2019_07` module.
- `package-managedapplications-2018-06` has 3 operations from 1 API versions: `2018-06-01`. Use crate feature `package-managedapplications-2018-06` to enable. The operations will be in the `package_managedapplications_2018_06` module.
- `package-managedapplications-2017-09` has 17 operations from 1 API versions: `2017-09-01`. Use crate feature `package-managedapplications-2017-09` to enable. The operations will be in the `package_managedapplications_2017_09` module.
- `package-managedapplications-2016-09` has 18 operations from 1 API versions: `2016-09-01-preview`. Use crate feature `package-managedapplications-2016-09` to enable. The operations will be in the `package_managedapplications_2016_09` module.

==> azure_mgmt_resources-0.3.0.crate: azure_mgmt_resources-0.3.0/README.md <==
# azure_mgmt_resources crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/resources/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-changes-2022-05`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-changes-2022-05` has 2 operations from 1 API versions: `2022-05-01`. Use crate feature `package-changes-2022-05` to enable. The operations will be in the `package_changes_2022_05` module.
- `package-changes-2022-03-01-preview` has 2 operations from 1 API versions: `2022-03-01-preview`. Use crate feature `package-changes-2022-03-01-preview` to enable. The operations will be in the `package_changes_2022_03_01_preview` module.
- `package-policy-2021-06` has 41 operations from 4 API versions: `2020-06-01`, `2020-07-01-preview`, `2020-09-01`, `2021-06-01`. Use crate feature `package-policy-2021-06` to enable. The operations will be in the `package_policy_2021_06` module.
- `package-privatelinks-2020-05` has 9 operations from 1 API versions: `2020-05-01`. Use crate feature `package-privatelinks-2020-05` to enable. The operations will be in the `package_privatelinks_2020_05` module.
- `package-locks-2020-05` has 17 operations from 1 API versions: `2020-05-01`. Use crate feature `package-locks-2020-05` to enable. The operations will be in the `package_locks_2020_05` module.
- `package-resources-2021-04` has 95 operations from 1 API versions: `2021-04-01`. Use crate feature `package-resources-2021-04` to enable. The operations will be in the `package_resources_2021_04` module.
- `package-locks-2017-04` has 17 operations from 1 API versions: `2017-04-01`. Use crate feature `package-locks-2017-04` to enable. The operations will be in the `package_locks_2017_04` module.
- `package-preview-2020-08` has 25 operations from 1 API versions: `2020-08-21-preview`. Use crate feature `package-preview-2020-08` to enable. The operations will be in the `package_preview_2020_08` module.
- `package-subscriptions-2021-01` has 6 operations from 1 API versions: `2021-01-01`. Use crate feature `package-subscriptions-2021-01` to enable. The operations will be in the `package_subscriptions_2021_01` module.
- `package-deploymentscripts-2020-10` has 8 operations from 1 API versions: `2020-10-01`. Use crate feature `package-deploymentscripts-2020-10` to enable. The operations will be in the `package_deploymentscripts_2020_10` module.
- `package-deploymentscripts-2019-10-preview` has 8 operations from 1 API versions: `2019-10-01-preview`. Use crate feature `package-deploymentscripts-2019-10-preview` to enable. The operations will be in the `package_deploymentscripts_2019_10_preview` module.
- `package-features-2021-07` has 11 operations from 1 API versions: `2021-07-01`. Use crate feature `package-features-2021-07` to enable. The operations will be in the `package_features_2021_07` module.
- `package-features-2015-12` has 6 operations from 1 API versions: `2015-12-01`. Use crate feature `package-features-2015-12` to enable. The operations will be in the `package_features_2015_12` module.
- `package-locks-2016-09` has 17 operations from 1 API versions: `2016-09-01`. Use crate feature `package-locks-2016-09` to enable. The operations will be in the `package_locks_2016_09` module.
- `package-locks-2015-01` has 11 operations from 1 API versions: `2015-01-01`. Use crate feature `package-locks-2015-01` to enable. The operations will be in the `package_locks_2015_01` module.
- `package-policy-2019-09` has 30 operations from 1 API versions: `2019-09-01`. Use crate feature `package-policy-2019-09` to enable. The operations will be in the `package_policy_2019_09` module.
- `package-policy-2019-06` has 29 operations from 1 API versions: `2019-06-01`. Use crate feature `package-policy-2019-06` to enable. The operations will be in the `package_policy_2019_06` module.
- `package-policy-2019-01` has 29 operations from 1 API versions: `2019-01-01`. Use crate feature `package-policy-2019-01` to enable. The operations will be in the `package_policy_2019_01` module.
- `package-policy-2018-05` has 29 operations from 1 API versions: `2018-05-01`. Use crate feature `package-policy-2018-05` to enable. The operations will be in the `package_policy_2018_05` module.
- `package-policy-2018-03` has 29 operations from 1 API versions: `2018-03-01`. Use crate feature `package-policy-2018-03` to enable. The operations will be in the `package_policy_2018_03` module.
- `package-policy-2017-06` has 29 operations from 2 API versions: `2016-12-01`, `2017-06-01-preview`. Use crate feature `package-policy-2017-06` to enable. The operations will be in the `package_policy_2017_06` module.
- `package-pure-policy-2017-06` has 19 operations from 1 API versions: `2017-06-01-preview`. Use crate feature `package-pure-policy-2017-06` to enable. The operations will be in the `package_pure_policy_2017_06` module.
- `package-templatespecs-2022-02` has 15 operations from 1 API versions: `2022-02-01`. Use crate feature `package-templatespecs-2022-02` to enable. The operations will be in the `package_templatespecs_2022_02` module.
- `package-templatespecs-2021-05` has 11 operations from 1 API versions: `2021-05-01`. Use crate feature `package-templatespecs-2021-05` to enable. The operations will be in the `package_templatespecs_2021_05` module.
- `package-templatespecs-2021-03-preview` has 11 operations from 1 API versions: `2021-03-01-preview`. Use crate feature `package-templatespecs-2021-03-preview` to enable. The operations will be in the `package_templatespecs_2021_03_preview` module.
- `package-templatespecs-2019-06-preview` has 11 operations from 1 API versions: `2019-06-01-preview`. Use crate feature `package-templatespecs-2019-06-preview` to enable. The operations will be in the `package_templatespecs_2019_06_preview` module.
- `package-policy-2016-12` has 19 operations from 1 API versions: `2016-12-01`. Use crate feature `package-policy-2016-12` to enable. The operations will be in the `package_policy_2016_12` module.
- `package-policy-2016-04` has 13 operations from 1 API versions: `2016-04-01`. Use crate feature `package-policy-2016-04` to enable. The operations will be in the `package_policy_2016_04` module.
- `package-policy-2015-10` has 13 operations from 1 API versions: `2015-10-01-preview`. Use crate feature `package-policy-2015-10` to enable. The operations will be in the `package_policy_2015_10` module.
- `package-resources-2021-01` has 94 operations from 1 API versions: `2021-01-01`. Use crate feature `package-resources-2021-01` to enable. The operations will be in the `package_resources_2021_01` module.
- `package-resources-2020-10` has 94 operations from 1 API versions: `2020-10-01`. Use crate feature `package-resources-2020-10` to enable. The operations will be in the `package_resources_2020_10` module.
- `package-resources-2020-08` has 93 operations from 1 API versions: `2020-08-01`. Use crate feature `package-resources-2020-08` to enable. The operations will be in the `package_resources_2020_08` module.
- `package-resources-2020-06` has 93 operations from 1 API versions: `2020-06-01`. Use crate feature `package-resources-2020-06` to enable. The operations will be in the `package_resources_2020_06` module.
- `package-resources-2019-10` has 92 operations from 1 API versions: `2019-10-01`. Use crate feature `package-resources-2019-10` to enable. The operations will be in the `package_resources_2019_10` module.
- `package-resources-2019-08` has 86 operations from 1 API versions: `2019-08-01`. Use crate feature `package-resources-2019-08` to enable. The operations will be in the `package_resources_2019_08` module.
- `package-resources-2019-07` has 86 operations from 1 API versions: `2019-07-01`. Use crate feature `package-resources-2019-07` to enable. The operations will be in the `package_resources_2019_07` module.
- `package-resources-2019-0510` has 64 operations from 1 API versions: `2019-05-10`. Use crate feature `package-resources-2019-0510` to enable. The operations will be in the `package_resources_2019_0510` module.
- `package-resources-2019-05` has 62 operations from 1 API versions: `2019-05-01`. Use crate feature `package-resources-2019-05` to enable. The operations will be in the `package_resources_2019_05` module.
- `package-resources-2019-03` has 52 operations from 1 API versions: `2019-03-01`. Use crate feature `package-resources-2019-03` to enable. The operations will be in the `package_resources_2019_03` module.
- `package-resources-2018-05` has 52 operations from 1 API versions: `2018-05-01`. Use crate feature `package-resources-2018-05` to enable. The operations will be in the `package_resources_2018_05` module.
- `package-resources-2018-02` has 41 operations from 1 API versions: `2018-02-01`. Use crate feature `package-resources-2018-02` to enable. The operations will be in the `package_resources_2018_02` module.
- `package-resources-2017-05` has 41 operations from 1 API versions: `2017-05-10`. Use crate feature `package-resources-2017-05` to enable. The operations will be in the `package_resources_2017_05` module.
- `package-resources-2016-09` has 40 operations from 1 API versions: `2016-09-01`. Use crate feature `package-resources-2016-09` to enable. The operations will be in the `package_resources_2016_09` module.
- `package-resources-2016-07` has 35 operations from 1 API versions: `2016-07-01`. Use crate feature `package-resources-2016-07` to enable. The operations will be in the `package_resources_2016_07` module.
- `package-resources-2016-02` has 35 operations from 1 API versions: `2016-02-01`. Use crate feature `package-resources-2016-02` to enable. The operations will be in the `package_resources_2016_02` module.
- `package-resources-2015-11` has 47 operations from 1 API versions: `2015-11-01`. Use crate feature `package-resources-2015-11` to enable. The operations will be in the `package_resources_2015_11` module.
- `package-subscriptions-2020-01` has 7 operations from 1 API versions: `2020-01-01`. Use crate feature `package-subscriptions-2020-01` to enable. The operations will be in the `package_subscriptions_2020_01` module.
- `package-subscriptions-2019-11` has 7 operations from 1 API versions: `2019-11-01`. Use crate feature `package-subscriptions-2019-11` to enable. The operations will be in the `package_subscriptions_2019_11` module.
- `package-subscriptions-2019-06` has 7 operations from 1 API versions: `2019-06-01`. Use crate feature `package-subscriptions-2019-06` to enable. The operations will be in the `package_subscriptions_2019_06` module.
- `package-subscriptions-2018-06` has 7 operations from 1 API versions: `2018-06-01`. Use crate feature `package-subscriptions-2018-06` to enable. The operations will be in the `package_subscriptions_2018_06` module.
- `package-subscriptions-2016-06` has 7 operations from 1 API versions: `2016-06-01`. Use crate feature `package-subscriptions-2016-06` to enable. The operations will be in the `package_subscriptions_2016_06` module.
- `package-subscriptions-2015-11` has 6 operations from 1 API versions: `2015-11-01`. Use crate feature `package-subscriptions-2015-11` to enable. The operations will be in the `package_subscriptions_2015_11` module.
- `package-links-2016-09` has 6 operations from 1 API versions: `2016-09-01`. Use crate feature `package-links-2016-09` to enable. The operations will be in the `package_links_2016_09` module.
- `package-managedapplications-2019-07` has 25 operations from 1 API versions: `2019-07-01`. Use crate feature `package-managedapplications-2019-07` to enable. The operations will be in the `package_managedapplications_2019_07` module.
- `package-managedapplications-2018-06` has 18 operations from 1 API versions: `2018-06-01`. Use crate feature `package-managedapplications-2018-06` to enable. The operations will be in the `package_managedapplications_2018_06` module.
- `package-managedapplications-2017-09` has 17 operations from 1 API versions: `2017-09-01`. Use crate feature `package-managedapplications-2017-09` to enable. The operations will be in the `package_managedapplications_2017_09` module.
- `package-managedapplications-2016-09` has 18 operations from 1 API versions: `2016-09-01-preview`. Use crate feature `package-managedapplications-2016-09` to enable. The operations will be in the `package_managedapplications_2016_09` module.
